TwitchApi.Bits.GetBitsLeaderboard (TwitchApi v0.1.0) View Source

⛔ This module is autogenerated please do not modify manually.

Example request from twitch api docs:

descriptions:

This gets information about the top two Bits leaderboard entries for the user specified by Bearer token cfabdegwdoklmawdzdo98xt2fo512y. Information is returned for the current week.

requests:

curl -X GET 'https://api.twitch.tv/helix/bits/leaderboard?count=2&period=week'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'

Example response from twitch api docs:

descriptions:

responses:

{"data":[{"user_id":"158010205","user_login":"tundracowboy","user_name":"TundraCowboy","rank":1,"score":12543},{"user_id":"7168163","user_login":"topramens","user_name":"Topramens","rank":2,"score":6900}],"date_range":{"started_at":"2018-02-05T08:00:00Z","ended_at":"2018-02-12T08:00:00Z"},"total":2}

Link to this section Summary

Functions

Description:

Gets a ranked list of Bits leaderboard information for an authorized broadcaster.

Link to this section Types

Specs

count() :: %{count: integer()}

Specs

period() :: %{period: String.t()}

Specs

started_at() :: %{started_at: String.t()}

Specs

user_id() :: %{user_id: String.t()}

Specs

user_info() :: %{user_id: integer() | binary()} | %{user_name: binary()}

Link to this section Functions

Specs

call(count() | period() | started_at() | user_id(), user_info()) ::
  {:ok, Finch.Response.t()} | {:error, Exception.t()}

Description:

Gets a ranked list of Bits leaderboard information for an authorized broadcaster.

Required authentication:

OAuth token required Required scope: bits:read

Required authorization: