TwitchApi.ChannelPoints.GetCustomRewardRedemption (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
This example lists custom reward redemptions for a specific reward: This example gets custom reward redemptions by ID.
requests:
curl -X GET 'https://api.twitch.tv/helix/channel_points/custom_rewards/redemptions?broadcaster_id=274637212&reward_id=92af127c-7326-4483-a52b-b0da0be61c01&id=17fa2df1-ad76-4804-bfa5-a40ef63efe63'
-H'Client-Id: gx2pv4208cff0ig9ou7nk3riccffxt'
-H'Authorization: Bearer vjxv3i0l4zxru966wsnwji51tmpkj2'
curl -X GET 'https://api.twitch.tv/helix/channel_points/custom_rewards/redemptions?broadcaster_id=274637212&reward_id=92af127c-7326-4483-a52b-b0da0be61c01&status=CANCELED'
-H'Client-Id: gx2pv4208cff0ig9ou7nk3riccffxt'
-H'Authorization: Bearer vjxv3i0l4zxru966wsnwji51tmpkj2'
Example response from twitch api docs:
descriptions:
responses:
{"data":[{"broadcaster_name":"torpedo09","broadcaster_login":"torpedo09","broadcaster_id":"274637212","id":"17fa2df1-ad76-4804-bfa5-a40ef63efe63","user_id":"274637212","user_name":"torpedo09","user_input":"","status":"CANCELED","redeemed_at":"2020-07-01T18:37:32Z","reward":{"id":"92af127c-7326-4483-a52b-b0da0be61c01","title":"game analysis","prompt":"","cost":50000}}]} {"data":[{"broadcaster_name":"torpedo09","broadcaster_login":"torpedo09","broadcaster_id":"274637212","id":"17fa2df1-ad76-4804-bfa5-a40ef63efe63","user_login":"torpedo09","user_id":"274637212","user_name":"torpedo09","user_input":"","status":"CANCELED","redeemed_at":"2020-07-01T18:37:32Z","reward":{"id":"92af127c-7326-4483-a52b-b0da0be61c01","title":"game analysis","prompt":"","cost":50000}}],"pagination":{"cursor":"eyJiIjpudWxsLCJhIjp7IkN1cnNvciI6Ik1UZG1ZVEprWmpFdFlXUTNOaTAwT0RBMExXSm1ZVFV0WVRRd1pXWTJNMlZtWlRZelgxOHlNREl3TFRBM0xUQXhWREU0T2pNM09qTXlMakl6TXpFeU56RTFOMW89In19"}}
Link to this section Summary
Functions
Description:
Returns Custom Reward Redemption objects for a Custom Reward on a channel that was created by the same client_id.
Link to this section Types
Specs
after_query_param() :: %{after_query_param: String.t()}
Specs
broadcaster_id() :: %{broadcaster_id: String.t()}
Specs
first() :: %{first: integer()}
Specs
id() :: %{id: String.t()}
Specs
reward_id() :: %{reward_id: String.t()}
Specs
sort() :: %{sort: String.t()}
Specs
status() :: %{status: String.t()}
Specs
Link to this section Functions
Specs
call( broadcaster_id() | reward_id() | id() | status() | sort() | after_query_param() | first(), user_info() ) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
Returns Custom Reward Redemption objects for a Custom Reward on a channel that was created by the same client_id.
Required authentication:
User OAuth token Required scope: channel:read:redemptions