TwitchApi.Polls.EndPoll (TwitchApi v0.1.0) View Source

⛔ This module is autogenerated please do not modify manually.

Example request from twitch api docs:

descriptions:

Ends a specific poll for the TwitchDev channel, but allows the results to be visible for viewers.

requests:

curl -X PATCH 'https://api.twitch.tv/helix/polls'
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'
-H'Content-Type: application/json'
-d'{ "broadcaster_id":"141981764", "id":"ed961efd-8a3f-4cf5-a9d0-e616c590cd2a", "status":"TERMINATED" }'

Example response from twitch api docs:

descriptions:

responses:

{"data":[{"id":"ed961efd-8a3f-4cf5-a9d0-e616c590cd2a","broadcaster_id":"141981764","broadcaster_name":"TwitchDev","broadcaster_login":"twitchdev","title":"Heads or Tails?","choices":[{"id":"4c123012-1351-4f33-84b7-43856e7a0f47","title":"Heads","votes":0,"channel_points_votes":0,"bits_votes":0},{"id":"279087e3-54a7-467e-bcd0-c1393fcea4f0","title":"Tails","votes":0,"channel_points_votes":0,"bits_votes":0}],"bits_voting_enabled":false,"bits_per_vote":0,"channel_points_voting_enabled":true,"channel_points_per_vote":100,"status":"TERMINATED","duration":1800,"started_at":"2021-03-19T06:08:33.871278372Z","ended_at":"2021-03-19T06:11:26.746889614Z"}]}

Link to this section Summary

Functions

Description:

NEW End a poll that is currently active.

Link to this section Types

Specs

user_info() :: %{user_id: integer() | binary()} | %{user_name: binary()}

Link to this section Functions

Link to this function

call(body_params, user_info)

Specs

call(
  %{broadcaster_id: String.t(), id: String.t(), status: String.t()} | nil,
  user_info()
) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}

Description:

NEW End a poll that is currently active.

Required authentication:

Required authorization:

User OAuth tokenRequired scope: channel:manage:polls