TwitchApi.Schedule.UpdateChannelStreamScheduleSegment (TwitchApi v0.1.0) View Source

⛔ This module is autogenerated please do not modify manually.

Example request from twitch api docs:

descriptions:

Update a non-recurring stream schedule segment for the TwitchDev channel’s stream schedule.

requests:

curl -X PATCH 'https://api.twitch.tv/helix/schedule/segment?broadcaster_id=141981764&id=eyJzZWdtZW50SUQiOiJlNGFjYzcyNC0zNzFmLTQwMmMtODFjYS0yM2FkYTc5NzU5ZDQiLCJpc29ZZWFyIjoyMDIxLCJpc29XZWVrIjoyNn0='
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'-d'{ "duration": "120" }'

Example response from twitch api docs:

descriptions:

responses:

{"data":{"segments":[{"id":"eyJzZWdtZW50SUQiOiJlNGFjYzcyNC0zNzFmLTQwMmMtODFjYS0yM2FkYTc5NzU5ZDQiLCJpc29ZZWFyIjoyMDIxLCJpc29XZWVrIjoyNn0=","start_time":"2021-07-01T18:00:00Z","end_time":"2021-07-01T20:00:00Z","title":"TwitchDev Monthly Update // July 1, 2021","canceled_until":null,"category":{"id":"509670","name":"Science & Technology"},"is_recurring":false}],"broadcaster_id":"141981764","broadcaster_name":"TwitchDev","broadcaster_login":"twitchdev","vacation":null}}

Link to this section Summary

Functions

Description:

NEW Update a single scheduled broadcast or a recurring scheduled broadcast for a channel’s stream schedule.

Link to this section Types

Specs

broadcaster_id() :: %{broadcaster_id: String.t()}

Specs

id() :: %{id: String.t()}

Specs

user_info() :: %{user_id: integer() | binary()} | %{user_name: binary()}

Link to this section Functions

Specs

call(broadcaster_id() | id(), user_info()) ::
  {:ok, Finch.Response.t()} | {:error, Exception.t()}

Description:

NEW Update a single scheduled broadcast or a recurring scheduled broadcast for a channel’s stream schedule.

Required authentication:

Required authorization:

User OAuth TokenRequired scope: channel:manage:schedule