TwitchApi.Search.SearchCategories (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
This request queries for games and categories.
requests:
curl -X GET 'https://api.twitch.tv/helix/search/categories?query=fort'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: wbmytr93xzw8zbg0p1izqyzzc5mbiz'
Example response from twitch api docs:
descriptions:
responses:
{"data":[{"id":"33214","name":"Fortnite","box_art_url":"https://static-cdn.jtvnw.net/ttv-boxart/Fortnite-{width}x{height}.jpg"},...],"pagination":{"cursor":"eyJiIjpudWxsLCJhIjp7IkN"}}
Link to this section Summary
Link to this section Types
Link to this section Functions
Specs
call(query() | first() | after_query_param()) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
Returns a list of games or categories that match the query via name either entirely or partially.
Required authentication:
OAuth or App Access Token required