TwitchApi.Streams.GetStreamMarkers (TwitchApi v0.1.0) View Source

⛔ This module is autogenerated please do not modify manually.

Example request from twitch api docs:

descriptions:

This returns the first 5 markers in the most recent stream of user 123.

requests:

curl -X GET 'https://api.twitch.tv/helix/streams/markers?user_id=123&first=5'
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'

Example response from twitch api docs:

descriptions:

responses:

{"data":[{"user_id":"123","user_name":"TwitchName","user_login":"twitchname","videos":[{"video_id":"456","markers":[{"id":"106b8d6243a4f883d25ad75e6cdffdc4","created_at":"2018-08-20T20:10:03Z","description":"hello, this is a marker!","position_seconds":244,"URL":"https://twitch.tv/videos/456?t=0h4m06s"},...]}]}],"pagination":{"cursor":"eyJiIjpudWxsLCJhIjoiMjk1MjA0Mzk3OjI1Mzpib29rbWFyazoxMDZiOGQ1Y"}}

Link to this section Summary

Functions

Description:

Gets a list of markers for either a specified user’s most recent stream or a specified VOD/video (stream), ordered by recency. A marker is an arbitrary point in a stream that the broadcaster wants to mark.

Link to this section Types

Specs

after_query_param() :: %{after_query_param: String.t()}

Specs

before() :: %{before: String.t()}

Specs

first() :: %{first: String.t()}

Specs

user_id() :: %{user_id: String.t()}

Specs

user_info() :: %{user_id: integer() | binary()} | %{user_name: binary()}

Specs

video_id() :: %{video_id: String.t()}

Link to this section Functions

Specs

call(
  user_id() | video_id() | after_query_param() | before() | first(),
  user_info()
) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}

Description:

Gets a list of markers for either a specified user’s most recent stream or a specified VOD/video (stream), ordered by recency. A marker is an arbitrary point in a stream that the broadcaster wants to mark.

Required authentication:

OAuth token required Required scope: user:read:broadcast

Required authorization: