TwitchApi.Streams.GetStreams (TwitchApi v0.1.0) View Source

⛔ This module is autogenerated please do not modify manually.

Example request from twitch api docs:

descriptions:

This gets information about the 20 most active streams. This gets information about the next 20 most active streams, after the ones specified in the prior response. The request includes as its after value, the cursor returned in the prior response.

requests:

curl -X GET 'https://api.twitch.tv/helix/streams?user_login=afro&user_login=cohhcarnage&user_login=lana_lux'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2' curl -X GET 'https://api.twitch.tv/helix/streams?first=20&after=eyJiIjp7IkN1cnNvciI6ImV5SnpJam8zT0RNMk5TNDBORFF4TlRjMU1UY3hOU3dpWkNJNlptRnNjMlVzSW5RaU9uUnlkV1Y5In0sImEiOnsiQ3Vyc29yIjoiZXlKeklqb3hOVGs0TkM0MU56RXhNekExTVRZNU1ESXNJbVFpT21aaGJITmxMQ0owSWpwMGNuVmxmUT09In19'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2' curl -X GET 'https://api.twitch.tv/helix/streams'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: wbmytr93xzw8zbg0p1izqyzzc5mbiz'

Example response from twitch api docs:

descriptions:

This gets information about three different specified streams using the ability to pass multiple logins. If a provided user is not live, they will not be included in the response.

responses:

{"data":[{"id":"40952121085","user_id":"101051819","user_login":"afro","user_name":"Afro","game_id":"32982","game_name":"Grand Theft Auto V","type":"live","title":"Jacob: Digital Den Laptops & Routers | NoPixel | !MAINGEAR !FCF","viewer_count":1490,"started_at":"2021-03-10T03:18:11Z","language":"en","thumbnail_url":"https://static-cdn.jtvnw.net/previews-ttv/live_user_afro-{width}x{height}.jpg","tag_ids":["6ea6bca4-4712-4ab9-a906-e3336a9d8039"],"is_mature":false},...],"pagination":{}} {"data":[{"id":"40944942733","user_id":"67931625","user_login":"amar","user_name":"Amar","game_id":"33214","game_name":"Fortnite","type":"live","title":"27h Stream Pringles Deathrun Map + 12k MK Turnier | !sub !JustLegends !Pc !yfood","viewer_count":14944,"started_at":"2021-03-09T16:59:39Z","language":"de","thumbnail_url":"https://static-cdn.jtvnw.net/previews-ttv/live_user_amar-{width}x{height}.jpg","tag_ids":["9166ad14-41f1-4b04-a3b8-c8eb838c6be6"],"is_mature":false},],"pagination":{"cursor":"eyJiIjp7IkN1cnNvciI6ImV5SnpJam94TkRrME5DNDFOekV5TXpBMU1UWTVNRElzSW1RaU9tWmhiSE5sTENKMElqcDBjblZsZlE9PSJ9LCJhIjp7IkN1cnNvciI6ImV5SnpJam81TlRFMkxqVTNOREF6TmpNNU9UTXpNaXdpWkNJNlptRnNjMlVzSW5RaU9uUnlkV1Y5In19"}} cursor after {"data":[{"id":"41375541868","user_id":"459331509","user_login":"auronplay","user_name":"auronplay","game_id":"494131","game_name":"Little Nightmares","type":"live","title":"hablamos y le damos a Little Nightmares 1","viewer_count":78365,"started_at":"2021-03-10T15:04:21Z","language":"es","thumbnail_url":"https://static-cdn.jtvnw.net/previews-ttv/live_user_auronplay-{width}x{height}.jpg","tag_ids":["d4bb9c58-2141-4881-bcdc-3fe0505457d1"],"is_mature":false},...],"pagination":{"cursor":"eyJiIjp7IkN1cnNvciI6ImV5SnpJam8zT0RNMk5TNDBORFF4TlRjMU1UY3hOU3dpWkNJNlptRnNjMlVzSW5RaU9uUnlkV1Y5In0sImEiOnsiQ3Vyc29yIjoiZXlKeklqb3hOVGs0TkM0MU56RXhNekExTVRZNU1ESXNJbVFpT21aaGJITmxMQ0owSWpwMGNuVmxmUT09In19"}}

Link to this section Summary

Functions

Description:

Gets information about active streams. Streams are returned sorted by number of current viewers, in descending order.

Link to this section Types

Specs

after_query_param() :: %{after_query_param: String.t()}

Specs

before() :: %{before: String.t()}

Specs

first() :: %{first: integer()}

Specs

game_id() :: %{game_id: String.t()}

Specs

language() :: %{language: String.t()}

Specs

user_id() :: %{user_id: String.t()}

Specs

user_login() :: %{user_login: String.t()}

Link to this section Functions

Specs

call(
  after_query_param()
  | before()
  | first()
  | game_id()
  | language()
  | user_id()
  | user_login()
) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}

Description:

Gets information about active streams. Streams are returned sorted by number of current viewers, in descending order.

Required authentication:

OAuth or App Access Token required

Required authorization: