TwitchApi.Users.BlockUser (TwitchApi v0.1.0) View Source

⛔ This module is autogenerated please do not modify manually.

Example request from twitch api docs:

descriptions:

This example blocks a user with an ID of 198704263 on behalf of the authenticated user.

requests:

curl -X PUT 'https://api.twitch.tv/helix/users/blocks?target_user_id=198704263'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: wbmytr93xzw8zbg0p1izqyzzc5mbiz'

Example response from twitch api docs:

descriptions:

responses:

204NoContent

Link to this section Summary

Functions

Description:

Blocks the specified user on behalf of the authenticated user.

Link to this section Types

Specs

reason() :: %{reason: String.t()}

Specs

source_context() :: %{source_context: String.t()}

Specs

target_user_id() :: %{target_user_id: String.t()}

Specs

user_info() :: %{user_id: integer() | binary()} | %{user_name: binary()}

Link to this section Functions

Specs

call(target_user_id() | source_context() | reason(), user_info()) ::
  {:ok, Finch.Response.t()} | {:error, Exception.t()}

Description:

Blocks the specified user on behalf of the authenticated user.

Required authentication:

OAuth user token required Required scope: user:manage:blocked_users

Required authorization: