TwitchApi.Videos.GetVideos (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
This gets information about the video with ID 335921245.
requests:
curl -X GET 'https://api.twitch.tv/helix/videos?id=335921245'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'
Example response from twitch api docs:
descriptions:
responses:
{"data":[{"id":"335921245","stream_id":null,"user_id":"141981764","user_login":"twitchdev","user_name":"TwitchDev","title":"Twitch Developers 101","description":"Welcome to Twitch development! Here is a quick overview of our products and information to help you get started.","created_at":"2018-11-14T21:30:18Z","published_at":"2018-11-14T22:04:30Z","url":"https://www.twitch.tv/videos/335921245","thumbnail_url":"https://static-cdn.jtvnw.net/cf_vods/d2nvs31859zcd8/twitchdev/335921245/ce0f3a7f-57a3-4152-bc06-0c6610189fb3/thumb/index-0000000000-%{width}x%{height}.jpg","viewable":"public","view_count":1863062,"language":"en","type":"upload","duration":"3m21s","muted_segments":[{"duration":30,"offset":120}]}],"pagination":{}}
Link to this section Summary
Link to this section Types
Specs
after_query_param() :: %{after_query_param: String.t()}
Specs
before() :: %{before: String.t()}
Specs
first() :: %{first: String.t()}
Specs
game_id() :: %{game_id: String.t()}
Specs
id() :: %{id: String.t()}
Specs
language() :: %{language: String.t()}
Specs
period() :: %{period: String.t()}
Specs
sort() :: %{sort: String.t()}
Specs
type() :: %{type: String.t()}
Specs
user_id() :: %{user_id: String.t()}
Link to this section Functions
Specs
call( id() | user_id() | game_id() | after_query_param() | before() | first() | language() | period() | sort() | type() ) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
Gets video information by one or more video IDs, user ID, or game ID.
Required authentication:
User OAuth Token or App Access Token