TwitchApi.Schedule.DeleteChannelStreamScheduleSegment (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
Delete a non-recurring stream schedule segment for the TwitchDev channel’s stream schedule.
requests:
curl -X DELETE 'https://api.twitch.tv/helix/schedule/segment?broadcaster_id=141981764&id=eyJzZWdtZW50SUQiOiI4Y2EwN2E2NC0xYTZkLTRjYWItYWE5Ni0xNjIyYzNjYWUzZDkiLCJpc29ZZWFyIjoyMDIxLCJpc29XZWVrIjoyMX0='
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'
Example response from twitch api docs:
descriptions:
responses:
204NoContent
Link to this section Summary
Functions
Description:
NEW Delete a single scheduled broadcast or a recurring scheduled broadcast for a channel’s stream schedule.
Link to this section Types
Link to this section Functions
Specs
call(broadcaster_id() | id(), user_info()) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
NEW Delete a single scheduled broadcast or a recurring scheduled broadcast for a channel’s stream schedule.
Required authentication:
Required authorization:
User OAuth TokenRequired scope: channel:manage:schedule