TwitchApi.Schedule.GetChannelStreamSchedule (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
Returns all scheduled events from the TwitchDev channel’s stream schedule.
requests:
curl -X GET 'https://api.twitch.tv/helix/schedule?broadcaster_id=141981764'
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'
Example response from twitch api docs:
descriptions:
responses:
{"data":{"segments":[{"id":"eyJzZWdtZW50SUQiOiJlNGFjYzcyNC0zNzFmLTQwMmMtODFjYS0yM2FkYTc5NzU5ZDQiLCJpc29ZZWFyIjoyMDIxLCJpc29XZWVrIjoyNn0=","start_time":"2021-07-01T18:00:00Z","end_time":"2021-07-01T19:00:00Z","title":"TwitchDev Monthly Update // July 1, 2021","canceled_until":null,"category":{"id":"509670","name":"Science & Technology"},"is_recurring":false},...],"broadcaster_id":"141981764","broadcaster_name":"TwitchDev","broadcaster_login":"twitchdev","vacation":null},"pagination":{}}
Link to this section Summary
Link to this section Types
Link to this section Functions
Specs
call( broadcaster_id() | id() | start_time() | utc_offset() | first() | after_query_param() ) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
NEW Gets all scheduled broadcasts or specific scheduled broadcasts from a channel’s stream schedule.
Required authentication:
Required authorization:
User OAuth Token or App Access Token