TwitchApi.Schedule.UpdateChannelStreamSchedule (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
Enable Vacation Mode and specify vacation dates for the TwitchDev channel’s stream schedule.
requests:
curl -X PATCH 'https://api.twitch.tv/helix/schedule/settings?broadcaster_id=141981764&is_vacation_enabled=true&vacation_start_time=2021-05-16T00:00:00Z&vacation_end_time=2021-05-23T00:00:00Z&timezone=America/New_York'
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'
Example response from twitch api docs:
descriptions:
responses:
204NoContent
Link to this section Summary
Functions
Description:
NEW Update the settings for a channel’s stream schedule.
Link to this section Types
Link to this section Functions
Specs
call( broadcaster_id() | is_vacation_enabled() | vacation_start_time() | vacation_end_time() | timezone(), user_info() ) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
NEW Update the settings for a channel’s stream schedule.
Required authentication:
Required authorization:
User OAuth TokenRequired scope: channel:manage:schedule