TwitchApi.Streams.CreateStreamMarker (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
This creates a marker at the current location in user 123’s stream.
requests:
curl -X POST 'https://api.twitch.tv/helix/streams/markers'
-H'Authorization: Bearer cfabdegwdoklmawdzdo98xt2fo512y'
-H'Client-Id: uo6dggojyb8d6soh92zknwmi5ej1q2'
-H'Content-Type: application/json'
-d'{"user_id":"123", "description":"hello, this is a marker!"}'
Example response from twitch api docs:
descriptions:
responses:
{"data":[{"id":123,"created_at":"2018-08-20T20:10:03Z","description":"hello, this is a marker!","position_seconds":244}]}
Link to this section Summary
Functions
Description:
Creates a marker in the stream of a user specified by user ID. A marker is an arbitrary point in a stream that the broadcaster wants to mark.
Link to this section Types
Specs
Link to this section Functions
Specs
call(%{user_id: String.t()} | nil, user_info()) ::
{:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
Creates a marker in the stream of a user specified by user ID. A marker is an arbitrary point in a stream that the broadcaster wants to mark.
Required authentication:
OAuth token required Required scope: channel:manage:broadcast