TwitchApi.Users.GetUserBlockList (TwitchApi v0.1.0) View Source
⛔ This module is autogenerated please do not modify manually.
Example request from twitch api docs:
descriptions:
This example gets a list of users blocked by the specified user.
requests:
curl -X GET 'https://api.twitch.tv/helix/users/blocks?broadcaster_id=141981764'
-H'Authorization: Bearer 2gbdx6oar67tqtcmt49t3wpcgycthx'
-H'Client-Id: wbmytr93xzw8zbg0p1izqyzzc5mbiz'
Example response from twitch api docs:
descriptions:
responses:
{"data":[{"user_id":"135093069","user_login":"bluelava","display_name":"BlueLava"},{"user_id":"27419011","user_login":"travistyoj","display_name":"TravistyOJ"}]}
Link to this section Summary
Functions
Description:
Gets a specified user’s block list. The list is sorted by when the block occurred in descending order (i.e. most recent block first).
Link to this section Types
Link to this section Functions
Specs
call(broadcaster_id() | first() | after_query_param(), user_info()) :: {:ok, Finch.Response.t()} | {:error, Exception.t()}
Description:
Gets a specified user’s block list. The list is sorted by when the block occurred in descending order (i.e. most recent block first).
Required authentication:
OAuth user token required Required scope: user:read:blocked_users